# Dataset Types 📚

Currently, there are six types of datasets that can be generated using SynthGenAI:

- [**Raw Datasets**](./raw_datasets.md)
- [**Instruction Datasets**](./instruction_datasets.md)
- [**Preference Datasets**](./preference_datasets.md)
- [**Sentiment Analysis Datasets**](./sentiment_analysis_datasets.md)
- [**Summarization Datasets**](./summarization_datasets.md)
- [**Text Classification Datasets**](./text_classification_datasets.md)

The datasets can be generated:

- **Synchronously** - each dataset entry is generated one by one
- **Asynchronously** - batch of dataset entries is generated at once
